rem @echo off
rem
rem file: cc_updt_pgen_sync_pbl_all.cmd - this batch file performs the following steps:
rem           1) runs ClearCase Update on the View;
rem           2) runs PowerGen sync PBLs with objects in the PBL directory;
rem           3) create path list of PBG files
rem           4) check-out all PBG files using path list of PBG files;
rem           5) recreates the PBG files;
rem           6) check-in all PBG files using path list of PBG files - fail check-in if identical (i.e. PBG did not change from rebuild);
rem           7) uncheck-out any PBG files using path list of PBG files that failed to check-in because they were identical;
rem
rem       This cmd file uses the PowerGen wild card OLF file since we are trying to build the PBG file.
rem
rem Syntax example: cc_updt_pgen_sync_pbl_all c:\efh_195_integration\efh_source
rem
rem Assumptions:
rem     1) powergen exe existes on local PC
rem     2) A PowerGen project file and olf must exist in the View Directory (e.g. c:\eFH_195_integration\eFH_source\)
rem     3) VOB view directory is on drive C:
rem     4) That this file will be executed at the VOB directory level (e.g. c:\eFH_195_integration\eFH_source\)
rem
rem Note: Be sure that Application as well as Project regen_target_option is set to "All Objects in All Referenced Libraries".
rem
rem Last Updt: 02/10/03
rem
rem Enhancements needed:
rem     abort in not in efh_source directory
rem
echo Update PBG files %DATE% %TIME% > pbg_updt.log
echo ----------------------------------------- >> pbg_updt.log
echo. >> pbg_updt.log
echo Run cleartool update >> pbg_updt.log
echo. >> pbg_updt.log
rem   step 1) run cc update on view
cleartool update
rem
rem
echo Run PowerGen Sync >> pbg_updt.log
echo. >> pbg_updt.log
rem   step 2) PowerGen Sync PBLs with Objects   options: NRP - Do NOT perform full regen after all last import. G - mark objects as registered
start /Wait c:\powergen\pwrGn8 /K=%CD%\powergen_project.gen %CD%\powergen_obj_list.olf /NRP /G
rem
rem
echo Create path list for PBG files >> pbg_updt.log
echo. >> pbg_updt.log
rem   step 3) Create path list of PBG files Options: /S = subdirectories; /B bare format - single column output - no heading or summary ; /L = lowercase
dir *.pbg /S /B /L > pbg_file_list.txt
rem
rem
echo Check-out the PBG files prior to rebuild >> pbg_updt.log
echo. >> pbg_updt.log
rem  step 4) Check-out the PBG files prior to rebuild
for /F  %%i in (pbg_file_list.txt) do cleartool co -nc %%i >> pbg_updt.log 2>&1
rem cleartool find . -nxname -name "*.pbg" -exec "cleartool co -nc %%CLEARCASE_PN%%"
rem
rem
echo Run PowerGen PBG file build >> pbg_updt.log
echo. >> pbg_updt.log
rem   step 5) PowerGen re-Build PBG files        options: /R root directory of application (path of vob e.g. C:\efh_195_integration\efh_source)
start /Wait c:\powergen\pwrGn8 /G=%CD%\powergen_project.gen /R=%CD%
rem
rem
echo Check-In the re-Built PBG files. Fail to check-in if identical >> pbg_updt.log
echo. >> pbg_updt.log
rem   step 6) Check-In the re-Built PBG files. Fail to check-in if identical (i.e. PBG did not change)
for /F  %%i in (pbg_file_list.txt) do cleartool ci -nc %%i  >> pbg_updt.log 2>&1
rem cleartool find . -nxname -name "*.pbg" -exec "cleartool ci -nc %%CLEARCASE_PN%%"
rem
rem
echo UnCheck-Out any PBG that did not get checked-in because it was identical to predecessor >> pbg_updt.log
echo. >> pbg_updt.log
rem   step 7) UnCheck-Out any PBG that did not get checked-in because it was identical to predecessor.
for /F  %%i in (pbg_file_list.txt) do cleartool unco -rm %%i  >> pbg_updt.log 2>&1
rem cleartool find . -nxname -name "*.pbg" -exec "cleartool unco -rm %%CLEARCASE_PN%%"
rem
echo. >> pbg_updt.log
echo. >> pbg_updt.log
echo Completed PBG file rebuild %DATE% %TIME% > pbg_updt.log
echo ----------------------------------------- >> pbg_updt.log
